% The purpose of this code is to generate 100 different files of a full ecg
% waveform that consists of a baseline, preictal, seizure and a 2nd
% baseline. 


for x = 1:100; % iterate 100 times 

beat1 = randi([1000,1200],1,1); % # of random beats generated for baseline
beat2 = randi([120,360],1,1); % # of random beats generated for preictal
beat3 = randi([60,120],1,1); % # of random beats generated for seizure 
beat4 = randi([60,120],1,1); % # of random beats generated for 2nd baseline 

[HRbaseline,baselinetime] = baseline(beat1,beat2,beat3); % call baseline function 
[HRpreictal,preictaltime] = preictal(beat1,beat2,beat3,baselinetime(end)); % call preictal function
[HRseizure,seizuretime] = seizure(beat1,beat2,beat3,preictaltime(end)); % call seizure function
[HRbaseline2,baseline2time] = baseline2(beat1,beat2,beat3,beat4,seizuretime(end)); % call 2nd baseline function 

 trim1 = trimmean(HRpreictal,25) - trimmean(HRbaseline,25); % normalize preictal phase to baseline 
 trim2 =trimmean(HRseizure,25) - trimmean(HRbaseline,25); % normalize seizure phase to baseline
 trim3 =trimmean(HRbaseline2,25) - trimmean(HRbaseline,25); % normalize 2nd baseline to baseline

%

simulation = [HRbaseline,HRpreictal-trim1,HRseizure-trim2,HRbaseline2-trim3]; 
finaltime = [baselinetime,preictaltime,seizuretime,baseline2time];

 
 A =[finaltime;simulation]; % makes 2 rows; first row is the time and 2nd row is the voltage
 B =[baselinetime(1);baselinetime(end);preictaltime(1);preictaltime(end);seizuretime(1);seizuretime(end)];
 % make 6 rows; noting the start and end time of each phase. 
 
 % convert arrays into a table 
 simulation = array2table(A,'RowNames',{'time','mV'}); 
 markers = array2table(B,'RowNames',{'Baselinstart','Baselineend', 'Preictalstart', 'Preictalend', 'Seizurestart','Seizure end'});
 
% create a new .txt file for each iteration. 
 sim = strcat('3rdsim',strcat(int2str(x)),'.txt');
 mark = strcat('3rdmark',strcat(int2str(x)),'.txt')
   
 writetable(simulation,sim,'Delimiter','\t');
 writetable(markers,mark,'Delimiter','\t');

end 






    


 